summaryrefslogtreecommitdiff
path: root/platform/x11
diff options
context:
space:
mode:
authorRémi Verschelde <rverschelde@gmail.com>2018-01-26 19:17:24 +0100
committerRémi Verschelde <rverschelde@gmail.com>2018-01-26 19:17:24 +0100
commit9ba5fb87f009faea406e3968f4d88234752d635b (patch)
tree85b7c69a2e1bdfc737a9e2251a0257ab962cc2e2 /platform/x11
parenta98e9496eb71554656c7c1eed9a69d20aed9886c (diff)
Bullet: allow unbundling only if > 2.87
Looks like we are using cutting edge methods which are not even if the current stable 2.87.
Diffstat (limited to 'platform/x11')
-rw-r--r--platform/x11/detect.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/platform/x11/detect.py b/platform/x11/detect.py
index 1c6bada815..5c8564376f 100644
--- a/platform/x11/detect.py
+++ b/platform/x11/detect.py
@@ -173,12 +173,12 @@ def configure(env):
env.ParseConfig('pkg-config libpng --cflags --libs')
if not env['builtin_bullet']:
# We need at least version 2.87
import subprocess
bullet_version = subprocess.check_output(['pkg-config', 'bullet', '--modversion']).strip()
- if bullet_version < "2.87":
+ if bullet_version < "2.88":
# Abort as system bullet was requested but too old
- print("Bullet: System version {0} does not match minimal requirements ({1}). Aborting.".format(bullet_version, "2.87"))
+ print("Bullet: System version {0} does not match minimal requirements ({1}). Aborting.".format(bullet_version, "2.88"))
sys.exit(255)
env.ParseConfig('pkg-config bullet --cflags --libs')
@@ -173,12 +173,12 @@ def configure(env):
env.ParseConfig('pkg-config libpng --cflags --libs')
if not env['builtin_bullet']:
- # We need at least version 2.87
+ # We need at least version 2.88
import subprocess
bullet_version = subprocess.check_output(['pkg-config', 'bullet', '--modversion']).strip()